@@ -21,7 +21,7 @@ logger = logging.getLogger(__name__)
 
 class IrocReader(GordoBaseDataProvider):
     def can_handle_tag(self, tag: SensorTag):
-        return self.base_path_from_asset(tag.asset) is not None
+        return bool(self.base_paths_from_asset(tag.asset))
 
     @capture_args
     def __init__(
@@ -75,9 +75,11 @@ class IrocReader(GordoBaseDataProvider):
                 f"Iroc reader called with train_end_date: {train_end_date} before train_start_date: {train_start_date}"
             )
 
-        base_paths_from_assets = list(
-            map(lambda tag: self.base_path_from_asset(tag.asset), tag_list)
-        )
+        base_paths_from_assets = []
+        for tag in tag_list:
+            base_paths = self.base_paths_from_asset(tag.asset)
+            if base_paths:
+                base_paths_from_assets.extend(base_paths)
         if len(set(base_paths_from_assets)) != 1:
             raise ValueError(
                 "Iroc reader found either more than one asset or no asset from the tag list provided"
@@ -177,7 +179,7 @@ class IrocReader(GordoBaseDataProvider):
             logger.warning(f"Problem parsing file {file_path}, skipping.")
             return None
 
-    def base_path_from_asset(self, asset: str):
+    def base_paths_from_asset(self, asset: str):
         """
         Resolves an asset code to the datalake basepath containing the data.
         Returns None if it does not match any of the asset codes we know.
@@ -197,10 +199,10 @@ class IrocReader(GordoBaseDataProvider):
             return None
         if path_spec.reader != self.reader_name:
             return None
-        full_path = path_spec.full_path(cast(FileSystem, self.storage))
+        full_paths = path_spec.full_paths(cast(FileSystem, self.storage))
 
-        logger.debug(f"Found asset code {asset}, returning {full_path}")
-        return full_path
+        logger.debug(f"Found asset code {asset}, returning {full_paths}")
+        return full_paths
 
 
 def read_iroc_file(
