@@ -98,15 +98,15 @@ class NcsLookup:
         return quote(tag_name, safe=" ")
 
     def tag_dirs_lookup(
-        self, base_dir: str, tag_list: List[SensorTag]
+        self, base_dirs: List[str], tag_list: List[SensorTag]
     ) -> Iterable[Tuple[SensorTag, Optional[str]]]:
         """
         Takes list of tags and find directories related to them in the data lake storage
 
         Parameters
         ----------
-        base_dir: str
-            Base directory where all of the tags are placed
+        base_dirs: List[str]
+            List of base directories where all of the tags are placed
         tag_list: List[SensorTag]
             List of the tags
 
@@ -117,13 +117,15 @@ class NcsLookup:
         tags = {}
         for tag in tag_list:
             tag_name = self.quote_tag_name(tag.name)
-            tags[tag_name] = tag
-        for path, file_info in self.storage.ls(base_dir):
-            if file_info is not None and file_info.isdir():
-                dir_path, file_name = self.storage.split(path)
-                if file_name in tags:
-                    yield tags[file_name], path
-                    del tags[file_name]
+            tags[tag_name.upper()] = tag
+        for base_dir in base_dirs:
+            for path, file_info in self.storage.ls(base_dir):
+                if file_info is not None and file_info.isdir():
+                    dir_path, file_name = self.storage.split(path)
+                    file_tag_name = file_name.upper()
+                    if file_tag_name in tags:
+                        yield tags[file_tag_name], path
+                        del tags[file_tag_name]
         for tag in tags.values():
             yield tag, None
 
@@ -165,10 +167,9 @@ class NcsLookup:
             found = False
             for ncs_file_type in ncs_file_types:
                 if ncs_file_type.check_partition(partition):
-                    for path_partition, path in ncs_file_type.paths(
-                        storage, tag_name, [partition]
+                    for path_partition, full_path in ncs_file_type.paths(
+                        storage, tag_dir, tag_name, [partition]
                     ):
-                        full_path = storage.join(tag_dir, path)
                         if storage.exists(full_path) and self._validate_file(full_path):
                             file_type = ncs_file_type.file_type
                             locations[partition] = Location(
@@ -225,11 +226,11 @@ class NcsLookup:
                     )
                 asset_path_specs.append((path_spec, asset_tags))
         else:
-            path_spec = PathSpec(NCS_READER_NAME, base_dir, "")
+            path_spec = PathSpec(NCS_READER_NAME, base_dir, [""])
             asset_path_specs.append((path_spec, tags))
         for path_spec, asset_tags in asset_path_specs:
             for tag, tag_dir in self.tag_dirs_lookup(
-                path_spec.full_path(storage), asset_tags
+                path_spec.full_paths(storage), asset_tags
             ):
                 yield tag, tag_dir
 
