@@ -3,7 +3,7 @@ import logging
 from concurrent.futures import ThreadPoolExecutor
 from datetime import datetime
 import timeit
-from typing import Iterable, List, Optional, Tuple, cast, Union
+from typing import Iterable, Iterator, List, Optional, Tuple, cast, Union
 
 import pandas as pd
 
@@ -124,10 +124,17 @@ class NcsReader(GordoBaseDataProvider):
         """
         Implements GordoBaseDataProvider, see base class for documentation
         """
-        return (
-            self.dl_base_path is not None
-            or self.base_path_from_asset(tag.asset) is not None
-        )
+        return self.dl_base_path is not None or self.base_paths_from_asset(tag.asset)
+
+    @staticmethod
+    def filter_series(
+        series: pd.Series,
+        train_start_date: datetime,
+        train_end_date: datetime,
+    ) -> Iterable[pd.Series]:
+        return series[
+            (series.index >= train_start_date) & (series.index < train_end_date)
+        ]
 
     def load_series(
         self,
@@ -153,20 +160,20 @@ class NcsReader(GordoBaseDataProvider):
             self.assets_config, tag_list, self.dl_base_path
         )
 
-        with ThreadPoolExecutor(max_workers=self.threads) as executor:
-            fetched_tags = executor.map(
-                lambda tag_dirs: self._load_series_mapper(
-                    tag_dirs, partitions, dry_run
-                ),
-                tag_dirs_iter,
-            )
-
-            for tag_frame_all_partitions in fetched_tags:
-                filtered = tag_frame_all_partitions[
-                    (tag_frame_all_partitions.index >= train_start_date)
-                    & (tag_frame_all_partitions.index < train_end_date)
-                ]
-                yield filtered
+        if self.threads:
+            with ThreadPoolExecutor(max_workers=self.threads) as executor:
+                fetched_tags = executor.map(
+                    lambda tag_dirs: self._load_series_mapper(
+                        tag_dirs, partitions, dry_run
+                    ),
+                    tag_dirs_iter,
+                )
+                for series in fetched_tags:
+                    yield self.filter_series(series, train_start_date, train_end_date)
+        else:
+            for tag_dirs in tag_dirs_iter:
+                series = self._load_series_mapper(tag_dirs, partitions, dry_run)
+                yield self.filter_series(series, train_start_date, train_end_date)
 
     def _load_series_mapper(
         self,
@@ -284,17 +291,21 @@ class NcsReader(GordoBaseDataProvider):
         pd.Series:
             Series with all partitions for one tag.
         """
-        tag_base_path = self.dl_base_path
-        if not tag_base_path:
-            tag_base_path = self.base_path_from_asset(tag.asset)
+        tag_base_paths: List[str] = []
+        if self.dl_base_path:
+            tag_base_paths = [self.dl_base_path]
+        if not tag_base_paths:
+            base_paths = self.base_paths_from_asset(tag.asset)
+            if base_paths:
+                tag_base_paths = base_paths
 
-        if not tag_base_path:
+        if not tag_base_paths:
             raise ValueError(f"Unable to find base path from tag {tag} ")
         logger.info(f"Downloading tag: {tag} for partitions: {partitions}")
 
         tag_dir = None
         for found_tag, dir_path in self.ncs_lookup.tag_dirs_lookup(
-            tag_base_path, [tag]
+            tag_base_paths, [tag]
         ):
             if found_tag == tag:
                 tag_dir = dir_path
@@ -309,7 +320,7 @@ class NcsReader(GordoBaseDataProvider):
         )
         return self.read_tag_locations(tag_locations, dry_run)
 
-    def base_path_from_asset(self, asset: str):
+    def base_paths_from_asset(self, asset: str) -> Optional[List[str]]:
         """
         Resolves an asset code to the datalake basepath containing the data.
         Returns None if it does not match any of the asset codes we know.
@@ -328,7 +339,7 @@ class NcsReader(GordoBaseDataProvider):
                 "Assets reader name should be equal '%s' and not '%s'"
                 % (self.reader_name, path_spec.reader)
             )
-        full_path = path_spec.full_path(self.storage)
+        full_paths = path_spec.full_paths(self.storage)
 
-        logger.debug(f"Found asset code {asset}, returning {full_path}")
-        return full_path
+        logger.debug(f"Found asset code {asset}, returning {full_paths}")
+        return full_paths
