@@ -164,7 +164,7 @@ class DataLakeProvider(GordoBaseDataProvider):
         train_end_date: datetime,
         tag_list: typing.List[SensorTag],
         dry_run: typing.Optional[bool] = False,
-        **kwargs
+        **kwargs,
     ) -> typing.Iterable[pd.Series]:
         """
         See
@@ -180,7 +180,12 @@ class DataLakeProvider(GordoBaseDataProvider):
         data_providers = self._get_sub_dataproviders()
 
         yield from load_series_from_multiple_providers(
-            data_providers, train_start_date, train_end_date, tag_list, dry_run, **kwargs,
+            data_providers,
+            train_start_date,
+            train_end_date,
+            tag_list,
+            dry_run,
+            **kwargs,
         )
 
     def _adl1_back_compatible_kwarg(
@@ -303,7 +308,7 @@ class InfluxDataProvider(GordoBaseDataProvider):
         train_end_date: datetime,
         tag_list: typing.List[SensorTag],
         dry_run: typing.Optional[bool] = False,
-        **kwargs
+        **kwargs,
     ) -> typing.Iterable[pd.Series]:
         """
         See GordoBaseDataProvider for documentation
@@ -433,7 +438,7 @@ class RandomDataProvider(GordoBaseDataProvider):
         train_end_date: datetime,
         tag_list: typing.List[SensorTag],
         dry_run: typing.Optional[bool] = False,
-        **kwargs
+        **kwargs,
     ) -> typing.Iterable[pd.Series]:
         if dry_run:
             raise NotImplementedError(
