@@ -107,6 +107,7 @@ class TimeSeriesDataset(GordoBaseDataset):
         interpolation_limit: str = "8H",
         filter_periods: Optional[dict] = None,
         process_metadata: bool = True,
+        **kwargs,
     ):
         """
         Creates a TimeSeriesDataset backed by a provided dataprovider.
@@ -173,6 +174,8 @@ class TimeSeriesDataset(GordoBaseDataset):
             See `filter_periods` class for details.
         process_metadata: bool
             Processing metadata if true
+        kwargs
+            Deprecated arguments
         """
         self.train_start_date = self._validate_dt(train_start_date)
         self.train_end_date = self._validate_dt(train_end_date)
@@ -223,6 +226,14 @@ class TimeSeriesDataset(GordoBaseDataset):
                 f"information"
             )
 
+        for name, value in kwargs.items():
+            logger.error(
+                "Deprecated argument %s=%s provided for %s",
+                name,
+                value,
+                self.__class__.__name__,
+            )
+
         super().__init__()
 
     def to_dict(self):
