@@ -19,7 +19,7 @@ TAG_TO_ASSET = [
     TagPatternToAsset(re.compile(r"^1125.", re.IGNORECASE), "1125-kvb"),
     TagPatternToAsset(re.compile(r"^tra.", re.IGNORECASE), "1130-troa"),
     TagPatternToAsset(re.compile(r"^asgb.", re.IGNORECASE), "1191-asgb"),
-    TagPatternToAsset(re.compile(r"^kri.", re.IGNORECASE), "1175-kri"),
+    TagPatternToAsset(re.compile(r"^kri.", re.IGNORECASE), "1175-kris"),
     TagPatternToAsset(re.compile(r"^1138.", re.IGNORECASE), "1138-val"),
     TagPatternToAsset(re.compile(r"^hd.", re.IGNORECASE), "1170-hd"),
     TagPatternToAsset(re.compile(r"^nor.", re.IGNORECASE), "1180-nor"),
@@ -32,9 +32,9 @@ TAG_TO_ASSET = [
     TagPatternToAsset(re.compile(r"^per.", re.IGNORECASE), "1299-perf"),
     TagPatternToAsset(re.compile(r"^gra.", re.IGNORECASE), "1755-gra"),
     TagPatternToAsset(re.compile(r"^hea.", re.IGNORECASE), "1760-hea"),
-    TagPatternToAsset(re.compile(r"^osc.", re.IGNORECASE), "1765-OSC"),
-    TagPatternToAsset(re.compile(r"^oss.", re.IGNORECASE), "1766-OSS"),
-    TagPatternToAsset(re.compile(r"^ose.", re.IGNORECASE), "1767-OSE"),
+    TagPatternToAsset(re.compile(r"^osc.", re.IGNORECASE), "1765-osc"),
+    TagPatternToAsset(re.compile(r"^oss.", re.IGNORECASE), "1766-oss"),
+    TagPatternToAsset(re.compile(r"^ose.", re.IGNORECASE), "1767-ose"),
     TagPatternToAsset(re.compile(r"^trb.", re.IGNORECASE), "1775-trob"),
     TagPatternToAsset(re.compile(r"^trc.", re.IGNORECASE), "1776-troc"),
     TagPatternToAsset(re.compile(r"^1900.", re.IGNORECASE), "1900-jsv"),
@@ -134,7 +134,7 @@ def normalize_sensor_tags(
             List of sensors
     asset : str
             Optional asset code to put on sensors that don't have it. If this is
-            provided we will not attempt to deduce the asset from the tagame.
+            provided we will not attempt to deduce the asset from the tag name.
     default_asset : str
             Optional asset code to put on sensors that dont have it and which we are not
             able to resolve to an asset.
